/**
 * @function doSignmod
 * @returns Promise
 */

"use strict";

const apemanpromise = require('apemanpromise');

/** @lends doSignmod */
function doSignmod(User, Sign, data, digest, signed) {
    return User.findById(signed.user.id)
        .then((user) => {
            if (!user) {
                return null;
            }
            return Sign.findAll({
                    where: {user_id: user.get('id')}
                })
                .then((signs) => {
                    return apemanpromise.all(
                        signs.map((sign) => {
                            let password = data.password;
                            if (!password) {
                                return sign;
                            }
                            return digest(password, sign.password_salt)
                                .then((hash) => {
                                    return sign.update({
                                        password_hash: hash,
                                        signmod_at: new Date()
                                    });
                                });
                        })
                    );
                })
                .then(() => {
                    delete data.password;
                    return user.update(data);
                })
                .then((user) => {
                    return Sign.findById(signed.id)
                        .then((sign) => {
                            let result = sign.toJSON();
                            result.user = user.toJSON();
                            return result;
                        })
                });
        });

}

module.exports = doSignmod;

